import { Attachment } from "./attachment.model";
import { AutocompleteGroupReplaceData, AutocompleteReplaceData, AutocompleteUserContactReplaceData } from "./autocomplete.data.model";
import { RecordedData } from "./recorder.model";
import { User } from "./user.data.model";
export declare class Comment {
    /**
     * Unique identifier for the comment pin annotation.
     *
     * Auto generated.
     */
    commentId: number;
    /**
     * This determines the comment content type.
     *
     * Default: 'text'.
     */
    type: 'text' | 'voice';
    /**
     * Comment Text.
     *
     */
    commentText?: string;
    /**
     * To check if comment text is available.
     */
    isCommentTextAvailable?: boolean;
    isCommentResolverUsed?: boolean;
    /**
     * Same comment text in HTML.
     *
     */
    commentHtml?: string;
    /**
     * Html content to replace the comment text when user accepts the comment.
     */
    replaceContentHtml?: string;
    /**
     * Text content to replace the comment text when user accepts the comment.
     */
    replaceContentText?: string;
    /**
     * Comment voice recording url.
     *
     */
    commentVoiceUrl?: string;
    /**
     * The user who created this comment text.
     *
     */
    from: User;
    /**
     * List of users that were tagged using @mentions to this comment.
     *
     */
    to?: User[];
    /**
     * Timestamp when this comment content was last updated.
     *
     * Auto generated.
     */
    lastUpdated?: Date;
    createdAt?: any;
    status: 'added' | 'updated';
    /**
     * List of attachments.
     */
    attachments: Attachment[];
    /**
     * List of recorded data.
     */
    recorders: RecordedData[];
    reactionAnnotationIds: string[];
    taggedUserContacts: AutocompleteUserContactReplaceData[];
    customList: AutocompleteReplaceData[];
    toOrganizationUserGroup: AutocompleteGroupReplaceData[];
    isDraft?: boolean;
    /**
   * Timestamp when the comment annotation was edited.
   *
   * Auto generated.
   */
    editedAt?: any;
    /**
     * To check if comment annotation is edited.
     *
     */
    isEdited?: boolean;
}
