import { FirebaseOptions } from "@angular/fire/app";
import { FeatureType } from "../../utils/enums";
export declare class Config {
    /**
     * Restrict Snippyly features to specific pages. You can specify partial URL strings.
     *
     * Default: All pages where snippyly script or snippyly web components are added.
     */
    urlAllowList?: string[];
    /**
     * Only allow the provided Snippyly features to run.
     *
     * Default: All features are enabled.
     */
    featureAllowList?: Array<FeatureType>;
    /**
     * Restrict Snippyly features to specific user plans.
     *
     * Default: All users.
     */
    userPlanAllowList?: string[];
    /**
     * Restrict Snippyly features to specific users.
     *
     * Default: All users.
     */
    userIdAllowList?: string[];
    /**
     * Restrict Snippyly features to specific groups/teams of users.
     *
     * Default: All groups/teams.
     */
    userGroupIdAllowList?: string[];
    /**
     * To enable/disable debug mode
     *
     * This change will be reflected after a page refresh
     */
    debugMode?: boolean;
    /**
     * To enable/disable prefers color scheme.
     * If this is set to true, then we will listen to changes on the
     * prefers-color-scheme media query to set the global theme of our components.
     */
    usePrefersColorScheme?: boolean;
    /**
     * To enable/disable advanced queries.
     *
     * Default: false
     */
    advancedQueriesDisabled?: boolean;
    /**
     * The domain of the API proxy.
     */
    apiProxyDomain?: string;
}
export interface ExtendedFirebaseOptions extends FirebaseOptions {
    storeDbId: string;
    region?: string;
}
export interface AdvancedQueries {
    advancedQueriesEnabled: boolean;
    advancedQueriesEnabledTime: number;
}
export interface DisableLogsConfig {
    warnings?: boolean;
    suppressAll?: boolean;
}
