export declare enum CommentStatus {
    NEWLY_ADDED = "newlyAdded",
    ADDED = "added",
    UPDATED = "updated",
    DELETED = "deleted",
    APPROVED = "approved",
    ASSIGNED = "assigned",
    STATUS_CHANGED = "statusChanged",
    PRIORITY_CHANGED = "priorityChanged",
    ACCESS_MODE_CHANGED = "accessModeChanged",
    CUSTOM_LIST_CHANGED = "customListChanged",
    ACCEPTED = "accepted",
    REJECTED = "rejected",
    REACTION_ADDED = "reactionAdded",
    REACTION_DELETED = "reactionDeleted",
    SUBSCRIBED = "subscribed",
    UNSUBSCRIBED = "unsubscribed"
}
export declare enum ResolverActions {
    COMMENT_ANNOTATION_ADD = "comment_annotation.add",
    COMMENT_ANNOTATION_DELETE = "comment_annotation.delete",
    COMMENT_ADD = "comment.add",
    COMMENT_DELETE = "comment.delete",
    COMMENT_UPDATE = "comment.update",
    REACTION_ADD = "reaction.add",
    REACTION_DELETE = "reaction.delete",
    ATTACHMENT_ADD = "attachment.add",
    ATTACHMENT_DELETE = "attachment.delete"
}
export declare const CommentEventTypes: {
    readonly ADD_COMMENT_ANNOTATION: "addCommentAnnotation";
    readonly DELETE_COMMENT_ANNOTATION: "deleteCommentAnnotation";
    readonly APPROVE_COMMENT_ANNOTATION: "approveCommentAnnotation";
    readonly ACCEPT_COMMENT_ANNOTATION: "acceptCommentAnnotation";
    readonly REJECT_COMMENT_ANNOTATION: "rejectCommentAnnotation";
    readonly SUBSCRIBE_COMMENT_ANNOTATION: "subscribeCommentAnnotation";
    readonly UNSUBSCRIBE_COMMENT_ANNOTATION: "unsubscribeCommentAnnotation";
    readonly ASSIGN_USER: "assignUser";
    readonly UPDATE_STATUS: "updateStatus";
    readonly UPDATE_PRIORITY: "updatePriority";
    readonly UPDATE_ACCESS: "updateAccess";
    readonly RESOLVE_COMMENT: "resolveComment";
    readonly ADD_COMMENT: "addComment";
    readonly UPDATE_COMMENT: "updateComment";
    readonly DELETE_COMMENT: "deleteComment";
    readonly ADD_ATTACHMENT: "addAttachment";
    readonly DELETE_ATTACHMENT: "deleteAttachment";
    readonly DELETE_RECORDING: "deleteRecording";
    readonly COPY_LINK: "copyLink";
    readonly ADD_REACTION: "addReaction";
    readonly DELETE_REACTION: "deleteReaction";
    readonly TOGGLE_REACTION: "toggleReaction";
    readonly COMMENT_SIDEBAR_DATA_INIT: "commentSidebarDataInit";
    readonly COMMENT_SIDEBAR_DATA_UPDATE: "commentSidebarDataUpdate";
    readonly AUTOCOMPLETE_SEARCH: "autocompleteSearch";
    readonly COMPOSER_CLICKED: "composerClicked";
};
export declare const RecorderEventTypes: {
    readonly TRANSCRIPTION_DONE: "transcriptionDone";
    readonly RECORDING_DONE: "recordingDone";
    readonly RECORDING_EDIT_DONE: "recordingEditDone";
    readonly DELETE_RECORDING: "deleteRecording";
    readonly ERROR: "error";
    readonly RECORDING_SAVE_INITIATED: "recordingSaveInitiated";
};
export declare const CoreEventTypes: {
    readonly VELT_BUTTON_CLICK: "veltButtonClick";
    readonly USER_UPDATE: "userUpdate";
    readonly INIT_UPDATE: "initUpdate";
    readonly DOCUMENT_INIT: "documentInit";
    readonly ERROR: "error";
};
export declare const LiveStateSyncEventTypes: {
    readonly ACCESS_REQUESTED: "accessRequested";
    readonly ACCESS_REQUEST_CANCELED: "accessRequestCanceled";
    readonly ACCESS_ACCEPTED: "accessAccepted";
    readonly ACCESS_REJECTED: "accessRejected";
    readonly EDITOR_ASSIGNED: "editorAssigned";
    readonly VIEWER_ASSIGNED: "viewerAssigned";
    readonly EDITOR_ON_DIFFERENT_TAB_DETECTED: "editorOnDifferentTabDetected";
};
export declare const PresenceEventTypes: {
    readonly MULTIPLE_USERS_ONLINE: "multipleUsersOnline";
    readonly USER_STATE_CHANGE: "userStateChange";
};
export declare const NotificationEventTypes: {
    readonly SETTINGS_UPDATED: "settingsUpdated";
};
export type CommentEventType = typeof CommentEventTypes[keyof typeof CommentEventTypes];
export type RecorderEventType = typeof RecorderEventTypes[keyof typeof RecorderEventTypes];
export type CoreEventType = typeof CoreEventTypes[keyof typeof CoreEventTypes];
export type LiveStateSyncEventType = typeof LiveStateSyncEventTypes[keyof typeof LiveStateSyncEventTypes];
export type PresenceEventType = typeof PresenceEventTypes[keyof typeof PresenceEventTypes];
export type NotificationEventType = typeof NotificationEventTypes[keyof typeof NotificationEventTypes];
export declare enum TagStatus {
    ADDED = "added",
    UPDATED = "updated",
    DELETED = "deleted",
    APPROVED = "approved",
    RESOLVED = "resolved"
}
export declare enum UserActionTypes {
    INVITE = "invite",
    REMOVE = "remove"
}
export declare enum HuddleActionTypes {
    CREATED = "created",
    JOINED = "joined"
}
export declare enum RecorderStatus {
    ADDED = "added",
    UPDATED = "updated",
    DELETED = "deleted",
    APPROVED = "approved",
    RESOLVED = "resolved"
}
export declare enum ArrowStatus {
    ADDED = "added",
    UPDATED = "updated",
    DELETED = "deleted"
}
export declare enum AreaStatus {
    ADDED = "added",
    UPDATED = "updated",
    DELETED = "deleted"
}
export declare enum DocumentViewsStatus {
    FIRST_VIEWED = "firstViewed"
}
export declare enum Features {
    AREA = "area",
    ARROW = "arrow",
    AUDIO_HUDDLE = "audioHuddle",
    COMMENT = "comment",
    MULTI_THREAD = "multiThread",
    CURSOR = "cursor",
    HUDDLE = "huddle",
    LIVE_STATE_SYNC = "liveStateSync",
    PRESENCE = "presence",
    TAG = "tag",
    RECORDER = "recorder",
    REWRITER = "rewriter",
    LIVE_SELECTION = "liveSelection",
    NOTIFICATION = "notification",
    REACTION = "reaction"
}
export declare enum AnalyticsFeatures {
    AREA = "area",
    ARROW = "arrow",
    AUDIO_HUDDLE = "audioHuddle",
    COMMENT = "comment",
    MULTI_THREAD = "multiThread",
    CURSOR = "cursor",
    HUDDLE = "huddle",
    LIVE_STATE_SYNC = "liveStateSync",
    PRESENCE = "presence",
    TAG = "tag",
    RECORDER = "recorder",
    REWRITER = "rewriter",
    LIVE_SELECTION = "liveSelection",
    NOTIFICATION = "notification",
    REACTION = "reaction",
    AREA_COMMENT = "areaComment",
    INLINE_COMMENT = "inlineComment",
    COMMENT_SIDEBAR = "commentSidebar"
}
export type FeatureType = 'area' | 'arrow' | 'audioHuddle' | 'comment' | 'cursor' | 'huddle' | 'liveStateSync' | 'presence' | 'recorder' | 'rewriter' | 'tag' | 'liveSelection' | 'notification' | 'reaction' | 'multiThread';
export declare enum DeviceType {
    DESKTOP = "Desktop",
    MOBILE = "Mobile",
    TABLET = "Tablet",
    MONITOR = "Monitor",
    UNKNOWN = "Unknown"
}
export declare enum Orientation {
    PORTRAIT = "portrait",
    LANDSCAPE = "landscape",
    UNKNOWN = "unknown"
}
export declare enum OrientationMediaQueries {
    Portrait = "(orientation: portrait)",
    Landscape = "(orientation: landscape)"
}
export declare enum GhostCommentType {
    DIFFERENT_DEVICE = "differentDevice",
    ELEMENT_DELETED = "elementDeleted"
}
export declare enum Roles {
    ADMIN = "Admin",
    COMMENTER = "Commenter"
}
export declare enum DocumentAccessType {
    PUBLIC = "public",
    RESTRICTED = "restricted",
    ORGANIZATION_PRIVATE = "organizationPrivate"
}
export declare enum DetectionStrategy {
    DEFAULT = "default",
    DYNAMIC_ID = "dynamicId"
}
export declare enum CommentAccessMode {
    PUBLIC = "public",
    PRIVATE = "private"
}
export declare enum UnreadIndicatorMode {
    MINIMAL = "minimal",
    VERBOSE = "verbose"
}
export declare enum ComposerMode {
    DEFAULT = "default",
    EXPANDED = "expanded"
}
export declare enum CommentCountType {
    TOTAL = "total",
    UNREAD = "unread"
}
export declare enum ServerConnectionState {
    ONLINE = "online",
    OFFLINE = "offline",
    PENDING_INIT = "pendingInit",
    PENDING_DATA = "pendingData"
}
export declare enum ContactListScopeForOrganizationUsers {
    ALL = "all",
    ORGANIZATION = "organization",
    ORGANIZATION_USER_GROUP = "organizationUserGroup",
    DOCUMENT = "document",
    FOLDER = "folder"
}
export type RecorderMode = 'audio' | 'video' | 'screen' | 'all' | string;
export type RecorderType = 'audio' | 'video' | 'screen';
export type RecorderFileFormat = 'mp3' | 'mp4' | 'webm';
export type RecorderLayoutMode = 'floating' | 'thread';
export type SupportedMimeType = 'audio' | 'video';
export type FirebaseRegion = 'usCentral1' | 'asiaSouthEast1' | 'europeWest1';
export type VideoEventType = 'play' | 'pause' | 'ratechange' | 'seeked' | 'timeupdate' | 'volumechange';
export type RewriterType = 'copywriter' | 'generic';
export type RecorderStatusType = 'started' | 'paused' | 'resumed' | 'stopped' | 'error' | null;
export type HuddleType = 'audio' | 'video' | 'presentation';
export type NotificationTabId = 'for-you' | 'all' | 'document' | 'people';
export type NotificationTabType = 'forYou' | 'all' | 'documents' | 'people';
export type NotificationSource = 'area' | 'arrow' | 'comment' | 'tag' | 'huddle' | 'userInvite' | 'user' | 'recorder' | 'huddleInvite' | 'userFeedback' | 'userContactUs' | 'userReportBug' | 'documentViews' | 'custom';
export type SingleEditorStatus = 'pending' | 'accepted' | 'rejected' | 'cancelled';
export type SingleEditorState = 'idle' | 'inProgress' | 'completed';
export type AudioWaveformVariant = 'expanded' | 'minified' | 'player' | 'preview' | 'preview-mini' | 'editor';
export type ActionButtonType = 'button' | 'button-toggle' | 'multi-select' | 'single-select';
export type DropdownPosition = 'left' | 'right' | 'center';
export type DevicePermissionType = 'audio' | 'video';
export type TranscriptionMode = 'floating' | 'embed' | 'summaryMode';
export type ComposerPosition = 'top' | 'bottom';
export type SortBy = 'lastUpdated' | 'createdAt';
export type SortOrder = 'asc' | 'desc';
export type MinimapPosition = 'left' | 'right';
export type FilterOptionLayout = 'dropdown' | 'checkbox';
export type FilterPanelPosition = 'menu' | 'bottomSheet';
export type OverlayOriginY = 'top' | 'center' | 'bottom';
export type OverlayOriginX = 'start' | 'center' | 'end';
export type SubtitlesMode = 'floating' | 'embed';
export type RecorderVariant = 'default' | 'embed';
export type ReactionPinType = 'timeline' | 'comment';
export type SidebarPosition = 'left' | 'right';
export type SidebarSortingCriteria = 'date' | 'unread' | null;
export type SidebarFilterCriteria = 'all' | 'read' | 'unread' | 'resolved';
export type SidebarFilterSearchType = 'people' | 'assigned' | 'tagged' | 'pages' | 'documents' | 'statuses' | 'priorities' | 'categories' | 'versions' | string;
export type InlineSortingCriteria = 'createdFirst' | 'createdLast' | 'updatedFirst' | 'updatedLast';
export type NotificationPanelMode = 'popover' | 'sidebar';
export type SidebarActionButtonType = 'default' | 'toggle';
export declare enum CommentSidebarSystemFiltersOperator {
    AND = "and",
    OR = "or"
}
/**
 * Type for notification settings accordion types
 */
export type NotificationSettingsAccordionType = 'inbox' | 'email' | string;
/**
 * Type for notification settings item options
 */
export type NotificationSettingsItemType = 'ALL' | 'MINE' | 'NONE' | string;
